@@ -32,8 +32,8 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x031104
-pyqt_version_str = "3.17.4"
+pyqt_version = 0x031106
+pyqt_version_str = "3.17.6"
 
 sip_min_version = 0x040600
 
@@ -505,15 +505,22 @@ def compile_qt_program(name, define=None, include_dir=None, lib_dir=None, lib=No
     except OSError:
         pass
 
-    if not opt_verbose and hasattr(os, "popen4"):
-        fin, fout = os.popen4(build)
+    if not opt_verbose:
+        try:
+            import subprocess
+
+            p = subprocess.Popen(build, shell=True, stdin=subprocess.PIPE,
+                    stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+
+            fout = p.stdout
+        except ImportError:
+            _, fout = os.popen4(build)
 
         # Read stdout and stderr until there is no more output.
         lout = fout.readline()
         while lout:
             lout = fout.readline()
 
-        fin.close()
         fout.close()
 
         try:
